<?php

namespace Litecms\StairStepsSetting\Providers;

use Illuminate\Support\ServiceProvider;

class StairStepsSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'stair_steps_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'stair_steps_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.stair_steps_setting', function ($app) {
            return $this->app->make('Litecms\StairStepsSetting\StairStepsSetting');
        });

                // Bind StairStepsSettings to repository
        $this->app->bind(
            'Litecms\StairStepsSetting\Interfaces\StairStepsSettingsRepositoryInterface',
            \Litecms\StairStepsSetting\Repositories\Eloquent\StairStepsSettingsRepository::class
        );

        $this->app->register(\Litecms\StairStepsSetting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\StairStepsSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.stair_steps_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/stair_steps_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/stair_steps_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/stair_steps_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
